@@ -178,10 +178,6 @@ sub fetch_column {
     return $me->rdbh->selectcol_arrayref($sql, undef, @bind);
 }
 
-sub _save_last_insert_id {
-    # Must be provided in a DBD specific method
-}
-
 =head3 C<insert>
 
   $table->insert(name => 'Richard', age => 103);
@@ -212,6 +208,31 @@ sub insert {
     return $rv;
 }
 
+sub _save_last_insert_id {
+    # Should be provided in a DBD specific method
+    # It is called after insert and must return the autogenerated ID
+
+    # my $me = shift;
+    # my $sth = shift;
+    # return $sth->{Database}->last_insert_id(undef, @$me{qw(Schema Name)}, undef);
+}
+
+=head3 C<last_insert_id>
+
+  $table->insert(name => 'Quentin');
+  my $row_id = $table->last_insert_id;
+
+Retreive the autogenerated ID (if there was one) from the last inserted row.
+
+Returns the ID or undef if it's unavailable.
+
+=cut
+
+sub last_insert_id {
+    my $me = shift;
+    $me->{LastInsertID};
+}
+
 =head3 C<delete>
 
   $table->delete(name => 'Richard', age => 103);
